==> PPDF_1_1.zip: PubMedPDF/upload_wopmid.php <==
<?php
	include("../../mainfile.php");
	include (XOOPS_ROOT_PATH."/header.php");
	include "style.php";
	include "include/conn.php";
	include "include/db.php";
	include "include/xml.php";

	## without pmid registration
	if(@$_POST["upload"]){

		if(ereg("^[^_A-Za-z0-9]+$",@$_POST["title_e"])){
			echo "You can only use alphabet in English title form.<br>";

		}elseif(!strlen(@$_POST["title_e"])){
			echo "You have to input English title form.<br>";

		}elseif(ereg("^[^_A-Za-z0-9]+$",@$_POST["author_e"])){
			echo "You can only use alphabet in English author form.<br>";

		}elseif(!strlen(@$_POST["author_e"])){
			echo "You have to input English author form.<br>";

		}else{

			$data[t] = trim(@$_POST["title_e"]);
			$data[t_jp] = trim(@$_POST["title_o"]);
			$data[a] = trim(@$_POST["author_e"]);
			$data[a_jp] = trim(@$_POST["author_o"]);
			$data[v] = trim(@$_POST["volume"]);
			$data[p] = trim(@$_POST["page"]);
			$data[ab] = trim(@$_POST["abstract"]);
			$data[jb] = @$_POST["jb"];
	
			$data[t] = str_replace( "'", "&#8242;", $data[t] );
			$data[t_jp] = str_replace( "'", "&#8242;", $data[t_jp] );
			$data[a] = str_replace( "'", "&#8242;", $data[a] );
			$data[a_jp] = str_replace( "'", "&#8242;", $data[a_jp] );
	
			if(@$_POST["jb"] == "j"){
				if ( @$_POST["selectedJournal0"] != "(unknown)" ) {
					$data[j] = @$_POST["selectedJournal0"] ;
				} else {
					$data[j] = "(unknown)";
				}
			}elseif(@$_POST["jb"] == "b"){
				if ( @$_POST["selectedJournal1"] != "(unknown)" ) {
					$data[j] = @$_POST["selectedJournal1"] ;
				} else {
					$data[j] = "(unknown)";
				}
			}
	
			$year = trim(@$_POST["year"]);
			if (  strlen($year) >= 1 ) {
				$data[y] = $year;
			} else {
				if ( @$_POST["selectedYear"] != 0 ) {
					$data[y] = @$_POST["selectedYear"] ;
				} else {
					$data[y] = "0000";
				}
			}

			$title = trim( $data[t] );
			$title = substr( $title, 0, 10 );
			
			$Author = "";
			$Authors = explode(",",$data[a]);
			foreach($Authors as $a){
				$a = trim($a);
				$Author .= $a.", ";
			}
			$data[a] = substr($Author, 0, -2);
			
			$wopmid_id = $data[y]."_".$data[a]."_".$data[j]."_".$data[v]."_".$data[p]."_".$title;
			$wopmid_id = str_replace( array(' ', ','), array('_', '~'), $wopmid_id );
			$data[c_t1] = $wopmid_id;

			## Check registration

			$sql = "SELECT * FROM ".$T_ID." WHERE Custom_t1='".$wopmid_id."'";
			$res = mysql_query($sql, $conn);

			if(mysql_num_rows($res) != 0){
				echo "This content is already registered.<br>";
			} else {	

				($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
				$seq_no = DB($data, $user);

				# ID number -> PMID for original content
				$sql  = "UPDATE ".$T_ID." SET PMID=";
				$sql .= "'-".$seq_no."'"." WHERE id=$seq_no;"; 
				$res  = mysql_query($sql, $conn);
	
				echo "<div class=\"pt\">"._MD_REG_RESULT."</div>";
				echo "<b>File name</b>: ".$wopmid_id.".xml<br>";
//				echo "<b>ID: </b>".$seq_num."<br>";
				echo "<b>Title: </b>".$data[t]."<br>";
				echo "<b>Author(s): </b>".$data[a]."<br>";
				echo "<b>Journal/Book: </b>".$data[j];
				if ( $data[jb] == "j" ) {
					echo "&nbsp;(journal)<br>";
				} else {
					echo "&nbsp;(book)<br>";
				}
				echo "<b>Volume: </b>".$data[v]."<br>";
//				echo "<b>Number: </b>".@$_POST["number"]."<br>";
				echo "<b>Pages: </b>".$data[p]."<br>";
				echo "<b>Year: </b>".$data[y]."<br>";
				echo "<b>Abstract: </b><br>".$data[ab]."<br>";

				# folder for uploaded file
				$up_pass = $xoopsModuleConfig['updir'];
				if(substr($up_pass,-1) != "/") $up_pass.="/";
				$up_pass = $up_pass."wopmid/";
//				$up_pass = "uploads";
				if(!is_dir($up_pass))	$rc = mkdir($up_pass, 0777);
	
				if(is_uploaded_file($_FILES['userfile']['tmp_name'])){
					$file_name = $_FILES['userfile']['name'];
					if(preg_match("/.*(\.pdf)$/i", $file_name)){
						$file_name = $wopmid_id.".pdf";
						copy($_FILES['userfile']['tmp_name'], $up_pass.$file_name);
						echo "<b>Upload file: </b> [$file_name] was uploaded.<br><br>";
					}else{
						echo "<b>error:</b><br>Extension of filename should be \".pdf\".<br>File upload has been failed.<br>";
					}
				}else{
					echo "<b>Upload file:</b> No upload file<br>";
				}
	
				GENERATE_XML($data);
			}
		}
	}
	
	echo "<br><a href=\"index.php\">HOME</a>";
	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_3_1.zip: PubMedPDF/upload_wopmid.php <==
<?php
	include("../../mainfile.php");
	include (XOOPS_ROOT_PATH."/header.php");
	include "style.php";
	include "include/conn.php";
	include "include/db.php";
	include "include/xml.php";
	include "include/news.php";
	include "include/wopmid.php";

	## without pmid registration
	if(@$_POST["upload"]){

		if(ereg("^[^_A-Za-z0-9]+$",@$_POST["title_e"])){
			echo "You can only use alphabet in English title form.<br>";

		}elseif(!strlen(@$_POST["title_e"])){
			echo "You have to input English title form.<br>";

		}elseif(ereg("^[^_A-Za-z0-9]+$",@$_POST["author_e"])){
			echo "You can only use alphabet in English author form.<br>";

		}elseif(!strlen(@$_POST["author_e"])){
			echo "You have to input English author form.<br>";

		}else{

			$data[t] = trim(@$_POST["title_e"]);
			$data[t_jp] = trim(@$_POST["title_o"]);
			$data[a] = trim(@$_POST["author_e"]);
			$data[a_jp] = trim(@$_POST["author_o"]);
			$data[v] = trim(@$_POST["volume"]);
			$data[p] = trim(@$_POST["page"]);
			$data[ab] = trim(@$_POST["abstract"]);
			$data[jb] = @$_POST["jb"];

			foreach($data as $key => $value){
				$data[$key] = str_replace("\"", "&#34;", $data[$key]);
			}

			if(@$_POST["jb"] == "j"){
				if ( @$_POST["selectedJournal0"] != "(unknown)" ) {
					$data[j] = @$_POST["selectedJournal0"] ;
				} else {
					$data[j] = "(unknown)";
				}
			}elseif(@$_POST["jb"] == "b"){
				if ( @$_POST["selectedJournal1"] != "(unknown)" ) {
					$data[j] = @$_POST["selectedJournal1"] ;
				} else {
					$data[j] = "(unknown)";
				}
			}
	
			$year = trim(@$_POST["year"]);
			if (  strlen($year) >= 1 ) {
				$data[y] = $year;
			} else {
				if ( @$_POST["selectedYear"] != 0 ) {
					$data[y] = @$_POST["selectedYear"] ;
				} else {
					$data[y] = "0000";
				}
			}

			$title = trim( $data[t] );
//			$title = substr( $title, 0, 10 );
			
			$Author = "";
			$Authors = explode(",",$data[a]);
			foreach($Authors as $a){
				$a = trim($a);
				$Author .= $a.", ";
			}
			$data[a] = substr($Author, 0, -2);

/*			
			$wopmid_id = $data[y]."_".$data[a]."_".$data[j]."_".$data[v]."_".$data[p]."_".$title;
			$wopmid_id = str_replace( array(' ', ','), array('_', '~'), $wopmid_id );
*/
			$wopmid_id = wopmid($data[y], $data[a], $data[j], $data[v], $data[p], $title);
			$data[c_t1] = $wopmid_id;
			
			## Check registration

			$sql = "SELECT * FROM ".$T_ID." WHERE Custom_t1='".$wopmid_id."'";
			$res = mysql_query($sql, $conn);

			if(mysql_num_rows($res) != 0){
				echo "This content is already registered.<br>";
			} else {	

				($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
				$seq_no = DB($data, $user);

				if($xoopsModuleConfig['news']){
					NEWS_REGISTER("Reg.wo.PMID", $data[t], $data[ab], $user);
				}

				# ID number -> PMID for original content
				$sql  = "UPDATE ".$T_ID." SET PMID=";
				$sql .= "'-".$seq_no."'"." WHERE id=$seq_no;"; 
				$res  = mysql_query($sql, $conn);
	
				echo "<div class=\"pt\">"._MD_REG_RESULT."</div>";
				echo "<b>File name</b>: ".$wopmid_id.".xml<br>";
//				echo "<b>ID: </b>".$seq_num."<br>";
				echo "<b>Title: </b>".$data[t]."<br>";
				echo "<b>Author(s): </b>".$data[a]."<br>";
				echo "<b>Journal/Book: </b>".$data[j];
				if ( $data[jb] == "j" ) {
					echo "&nbsp;(journal)<br>";
				} else {
					echo "&nbsp;(book)<br>";
				}
				echo "<b>Volume: </b>".$data[v]."<br>";
//				echo "<b>Number: </b>".@$_POST["number"]."<br>";
				echo "<b>Pages: </b>".$data[p]."<br>";
				echo "<b>Year: </b>".$data[y]."<br>";
				echo "<b>Abstract: </b><br>".$data[ab]."<br>";

				# folder for uploaded file
				$up_pass = $xoopsModuleConfig['updir'];
				if(substr($up_pass,-1) != "/") $up_pass.="/";
				$up_pass = $up_pass."wopmid/";
//				$up_pass = "uploads";
				if(!is_dir($up_pass))	$rc = mkdir($up_pass, 0777);
	
				if(is_uploaded_file($_FILES['userfile']['tmp_name'])){
					$file_name = $_FILES['userfile']['name'];
					if(preg_match("/.*(\.pdf)$/i", $file_name)){
						$file_name = $wopmid_id.".pdf";
						copy($_FILES['userfile']['tmp_name'], $up_pass.$file_name);
						echo "<b>Upload file: </b> [$file_name] was uploaded.<br><br>";
					}else{
						echo "<b>error:</b><br>Extension of filename should be \".pdf\".<br>File upload has been failed.<br>";
					}
				}else{
					echo "<b>Upload file:</b> No upload file<br>";
				}
	
				GENERATE_XML($data);
			}
		}
	}
	
	echo "<br><a href=\"index.php\">HOME</a>";
	include (XOOPS_ROOT_PATH."/footer.php");
?>
